Promotion

Enum Promotion 

pub(crate) enum Promotion {
    Direct,
    IntToLong,
    IntToFloat,
    IntToDouble,
    LongToFloat,
    LongToDouble,
    FloatToDouble,
    StringToBytes,
    BytesToString,
}
Defines the type of promotion to be applied during schema resolution.

Schema resolution may require promoting a writer’s data type to a reader’s data type. For example, an int can be promoted to a long, float, or double.

Variants



Direct

Direct read with no data type promotion.



IntToLong

Promotes an int to a long.



IntToFloat

Promotes an int to a float.



IntToDouble

Promotes an int to a double.



LongToFloat

Promotes a long to a float.



LongToDouble

Promotes a long to a double.



FloatToDouble

Promotes a float to a double.



StringToBytes

Promotes a string to bytes.



BytesToString

Promotes bytes to a string.