pub(crate) enum ResolvedField {
ToReader(usize),
Skip(AvroDataType),
}Expand description
Resolution information for record fields in the writer schema.
Variants
ToReader(usize)
Resolves to a field indexed in the reader schema.
Skip(AvroDataType)
For fields present in the writer’s schema but not the reader’s, this stores their data type. This is needed to correctly skip over these fields during deserialization.