UnionFieldKind

Enum UnionFieldKind 

enum UnionFieldKind {
Show 26 variants Null, Boolean, Int, Long, Float, Double, Bytes, String, Date, TimeMillis, TimeMicros, TimestampMillisUtc, TimestampMillisLocal, TimestampMicrosUtc, TimestampMicrosLocal, TimestampNanosUtc, TimestampNanosLocal, Duration, Fixed, Decimal, Enum, Array, Record, Map, Uuid, Union,
}

Variants



Null



Boolean



Int



Long



Float



Double



Bytes



String



Date



TimeMillis



TimeMicros



TimestampMillisUtc



TimestampMillisLocal



TimestampMicrosUtc



TimestampMicrosLocal



TimestampNanosUtc



TimestampNanosLocal



Duration



Fixed



Decimal



Enum



Array



Record



Map



Uuid



Union