HeaderInfo

Struct HeaderInfo 

pub struct HeaderInfo(Arc<HeaderInfoInner>);
Header information for an Avro OCF file.

The header can be parsed once and shared to construct multiple readers for the same file, and so this struct is designed to be cheaply clonable.

Tuple Fields

0: Arc<HeaderInfoInner>

Implementations

Source

impl HeaderInfo

pub(crate) fn new(header: Header, header_len: u64) -> Self

pub fn writer_schema(&self) -> Result<AvroSchema, AvroError>

Returns the writer schema for this file.

pub fn compression(&self) -> Result<Option<CompressionCodec>, AvroError>

Returns the CompressionCodec if any

pub fn header_len(&self) -> u64

Returns the length of the header in bytes.

pub fn sync(&self) -> [u8; 16]

Returns the sync token for this file.