AvroObjectReader

Struct AvroObjectReader 

pub struct AvroObjectReader { /* private fields */ }
Available on crate feature object_store only.
An implementation of an AsyncFileReader using the ObjectStore API.

Implementations

Source

impl AvroObjectReader

pub fn new(store: Arc<dyn ObjectStore>, path: Path) -> Self

Available on crate feature async only.

Creates a new Self from a store implementation and file location.

pub fn with_runtime(self, handle: Handle) -> Self

Available on crate feature async only.

Perform IO on the provided tokio runtime

Tokio is a cooperative scheduler, and relies on tasks yielding in a timely manner to service IO. Therefore, running IO and CPU-bound tasks, such as avro decoding, on the same tokio runtime can lead to degraded throughput, dropped connections and other issues. For more information see here.