pub struct HeaderInfo(Arc<HeaderInfoInner>);Expand description
Header information for an Avro OCF file.
The header can be parsed once and shared to construct multiple readers for the same file, and so this struct is designed to be cheaply cloneable.
Tuple Fields
0: Arc<HeaderInfoInner>Implementations
Sourceimpl HeaderInfo
impl HeaderInfo
pub(crate) fn new(header: Header, header_len: u64) -> Self
Sourcepub fn writer_schema(&self) -> Result<AvroSchema, AvroError>
pub fn writer_schema(&self) -> Result<AvroSchema, AvroError>
Returns the writer schema for this file.
Sourcepub fn compression(&self) -> Result<Option<CompressionCodec>, AvroError>
pub fn compression(&self) -> Result<Option<CompressionCodec>, AvroError>
Returns the CompressionCodec if any
Sourcepub fn header_len(&self) -> u64
pub fn header_len(&self) -> u64
Returns the length of the header in bytes.