FingerprintAlgorithm

Enum FingerprintAlgorithm 

pub enum FingerprintAlgorithm {
    Rabin,
    Id,
    Id64,
    MD5,
    SHA256,
}
Supported fingerprint algorithms for Avro schema identification. For use with Confluent Schema Registry IDs, set to None.

Variants



Rabin

64‑bit CRC‑64‑AVRO Rabin fingerprint.



Id

Represents a 32 bit fingerprint not based on a hash algorithm, (e.g., a 32-bit Schema Registry ID.)



Id64

Represents a 64 bit fingerprint not based on a hash algorithm, (e.g., a 64-bit Schema Registry ID.)



MD5

128-bit MD5 message digest.



SHA256

256-bit SHA-256 digest.