Nullability

Enum Nullability 

pub(crate) enum Nullability {
    NullFirst,
    NullSecond,
}
Avro types are not nullable, with nullability instead encoded as a union where one of the variants is the null type.

To accommodate this, we specially case two-variant unions where one of the variants is the null type, and use this to derive arrow’s notion of nullability

Variants



NullFirst

The nulls are encoded as the first union variant



NullSecond

The nulls are encoded as the second union variant

Implementations

Source

impl Nullability

pub(crate) fn non_null_index(&self) -> usize

Returns the index of the non-null variant in the union.