AvroSchema

Struct AvroSchema 

pub struct AvroSchema {
    pub json_string: String,
}
A wrapper for an Avro schema in its JSON string representation.

Fields

json_string: String

The Avro schema as a JSON string.

Implementations

Source

impl AvroSchema

pub fn new(json_string: String) -> Self

Creates a new AvroSchema from a JSON string.

pub fn fingerprint( &self, hash_type: FingerprintAlgorithm, ) -> Result<Fingerprint, ArrowError>

Returns the fingerprint of the schema, computed using the specified FingerprintAlgorithm.

The fingerprint is computed over the schema’s Parsed Canonical Form as defined by the Avro specification. Depending on hash_type, this will return one of the supported Fingerprint variants:

Note: FingerprintAlgorithm::Id or FingerprintAlgorithm::Id64 cannot be used to generate a fingerprint and will result in an error. If you intend to use a Schema Registry ID-based wire format, either use SchemaStore::set or load the Fingerprint::Id directly via Fingerprint::load_fingerprint_id or for Fingerprint::Id64 via Fingerprint::load_fingerprint_id64.

See also: https://avro.apache.org/docs/1.11.1/specification/#schema-fingerprints

Errors

Returns an error if deserializing the schema fails, if generating the canonical form of the schema fails, or if hash_type is FingerprintAlgorithm::Id.

Examples
use arrow_avro::schema::{AvroSchema, FingerprintAlgorithm};

let avro = AvroSchema::new("\"string\"".to_string());
let fp = avro.fingerprint(FingerprintAlgorithm::Rabin).unwrap();