Available on crate feature
async only.Expand description
Asynchronous implementation of Avro file reader.
This module provides AsyncAvroFileReader, which supports reading and decoding
the Avro OCF format from any source that implements AsyncFileReader.
Structs
- Async
Avro File Reader - An asynchronous Avro file reader that implements
Stream<Item = Result<RecordBatch, ArrowError>>. This uses anAsyncFileReaderto fetch data ranges as needed, starting with fetching the header, then reading all the blocks in the provided range where: - Avro
Object Reader object_store - An implementation of an AsyncFileReader using the
ObjectStoreAPI. - Reader
Builder - Builder for an asynchronous Avro file reader.
Traits
- Async
File Reader - The asynchronous interface used by
super::AsyncAvroFileReaderto read avro files
Functions
- read_
header_ info - Reads the Avro file header (magic, metadata, sync marker) asynchronously from
reader.