pub struct SpawnedReader<R> {
inner: R,
handle: Handle,
}Expand description
An AsyncFileReader that performs I/O on a separate tokio runtime.
Tokio is a cooperative scheduler, and relies on tasks yielding in a timely manner to service IO. Therefore, running IO and CPU-bound tasks, such as avro decoding, on the same tokio runtime can lead to degraded throughput, dropped connections and other issues. For more information see here.
This wrapper spawns each operation of the inner reader onto the provided
runtime [Handle], so that the runtime driving the avro decoding does not
also drive the I/O.
The inner reader must be Clone (typically an Arc’d handle to some
shared resource) as each spawned task requires a 'static copy of it.
Fields
inner: Rhandle: HandleImplementations
Sourceimpl<R> SpawnedReader<R>
impl<R> SpawnedReader<R>
Sourcepub fn new(inner: R, handle: Handle) -> Self
pub fn new(inner: R, handle: Handle) -> Self
Creates a new SpawnedReader that performs the I/O of inner on handle
Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Returns the inner reader