pub struct AvroSchema {
pub json_string: String,
}Expand description
A wrapper for an Avro schema in its JSON string representation.
Fields
json_string: StringThe Avro schema as a JSON string.
Implementations
Sourceimpl AvroSchema
impl AvroSchema
Sourcepub fn fingerprint(
&self,
hash_type: FingerprintAlgorithm,
) -> Result<Fingerprint, ArrowError>
pub fn fingerprint( &self, hash_type: FingerprintAlgorithm, ) -> Result<Fingerprint, ArrowError>
Returns the fingerprint of the schema, computed using the specified FingerprintAlgorithm.
The fingerprint is computed over the schema’s Parsed Canonical Form
as defined by the Avro specification. Depending on hash_type, this
will return one of the supported Fingerprint variants:
Fingerprint::RabinforFingerprintAlgorithm::RabinFingerprint::MD5forFingerprintAlgorithm::MD5Fingerprint::SHA256forFingerprintAlgorithm::SHA256
Note: FingerprintAlgorithm::Id or FingerprintAlgorithm::Id64 cannot be used to generate a fingerprint
and will result in an error. If you intend to use a Schema Registry ID-based
wire format, either use SchemaStore::set or load the Fingerprint::Id directly via Fingerprint::load_fingerprint_id or for
Fingerprint::Id64 via Fingerprint::load_fingerprint_id64.
See also: https://avro.apache.org/docs/1.11.1/specification/#schema-fingerprints
Errors
Returns an error if deserializing the schema fails, if generating the
canonical form of the schema fails, or if hash_type is FingerprintAlgorithm::Id.
Examples
use arrow_avro::schema::{AvroSchema, FingerprintAlgorithm};
let avro = AvroSchema::new("\"string\"".to_string());
let fp = avro.fingerprint(FingerprintAlgorithm::Rabin).unwrap();Trait Implementations
Sourceimpl Clone for AvroSchema
impl Clone for AvroSchema
Sourcefn clone(&self) -> AvroSchema
fn clone(&self) -> AvroSchema
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AvroSchema
impl Debug for AvroSchema
Sourceimpl<'de> Deserialize<'de> for AvroSchema
impl<'de> Deserialize<'de> for AvroSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for AvroSchema
impl PartialEq for AvroSchema
Sourceimpl Serialize for AvroSchema
impl Serialize for AvroSchema
Sourceimpl TryFrom<&Schema> for AvroSchema
impl TryFrom<&Schema> for AvroSchema
Sourcefn try_from(schema: &ArrowSchema) -> Result<Self, Self::Error>
fn try_from(schema: &ArrowSchema) -> Result<Self, Self::Error>
Converts an ArrowSchema to AvroSchema, delegating to
AvroSchema::from_arrow_with_options with None so that the
union null ordering is decided by Nullability::default().
Sourcetype Error = ArrowError
type Error = ArrowError
impl Eq for AvroSchema
impl StructuralPartialEq for AvroSchema